@@ -1,4 +1,4 @@
 from tps_dashboard_utils import colours
 from tps_dashboard_utils import dashboard
-from tps_dashboard_utils import data
+from tps_dashboard_utils import data_functions
 from tps_dashboard_utils import date_functions
